@@ -1,9 +1,11 @@
 package Courriel::Header;
-$Courriel::Header::VERSION = '0.36';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.39';
+
 use Courriel::Helpers qw( fold_header );
 use Courriel::Types qw( NonEmptyStr Str Streamable );
 use Encode qw( encode find_encoding );
@@ -40,7 +42,7 @@ has value => (
             @spec
         );
 
-        my $string = $self->name();
+        my $string = $self->name;
         $string .= ': ';
 
         $string .= $self->_maybe_encoded_value($charset);
@@ -64,7 +66,7 @@ sub as_string {
 {
     my $header_chunk = qr/
                              (?:
-                                 ^
+                                ^
                              |
                                  (?<ascii>[\x21-\x7e]+)   # printable ASCII (excluding space, \x20)
                              |
@@ -87,7 +89,7 @@ sub as_string {
         my $self    = shift;
         my $charset = shift;
 
-        my $value = $self->value();
+        my $value = $self->value;
         my @chunks;
 
         while ( $value =~ /\G$header_chunk/g ) {
@@ -120,7 +122,7 @@ sub as_string {
 sub _mime_encode {
     my $self    = shift;
     my $text    = shift;
-    my $charset = find_encoding(shift)->mime_name();
+    my $charset = find_encoding(shift)->mime_name;
 
     my $head = '=?' . $charset . '?B?';
     my $tail = '?=';
@@ -133,7 +135,7 @@ sub _mime_encode {
 
     my @result;
     my $chunk = q{};
-    while ( length( my $chr = substr( $text, 0, 1, '' ) ) ) {
+    while ( length( my $chr = substr( $text, 0, 1, q{} ) ) ) {
         my $chr = encode( $charset, $chr, 0 );
 
         if ( length($chunk) + length($chr) > $real_length ) {
@@ -150,7 +152,7 @@ sub _mime_encode {
     return join q{ }, @result;
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -166,12 +168,12 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.36
+version 0.39
 
 =head1 SYNOPSIS
 
   my $subject = $headers->get('subject');
-  print $subject->value();
+  print $subject->value;
 
 =head1 DESCRIPTION
 
@@ -223,7 +225,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
