@@ -1,12 +1,11 @@
 package Courriel::Role::Part;
-{
-  $Courriel::Role::Part::VERSION = '0.30';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.39';
+
 use Courriel::Header::ContentType;
 use Courriel::Header::Disposition;
 use Courriel::Types qw( NonEmptyStr );
@@ -15,7 +14,7 @@ use Moose::Role;
 
 with 'Courriel::Role::Streams';
 
-requires qw( _default_mime_type _stream_content );
+requires qw( _stream_content );
 
 has headers => (
     is       => 'rw',
@@ -43,7 +42,7 @@ has content_type => (
 after BUILD => sub {
     my $self = shift;
 
-    $self->_maybe_set_content_type_in_headers();
+    $self->_maybe_set_content_type_in_headers;
 
     return;
 };
@@ -51,7 +50,7 @@ after BUILD => sub {
 after _set_headers => sub {
     my $self = shift;
 
-    $self->_maybe_set_content_type_in_headers();
+    $self->_maybe_set_content_type_in_headers;
 
     return;
 };
@@ -59,21 +58,23 @@ after _set_headers => sub {
 sub _maybe_set_content_type_in_headers {
     my $self = shift;
 
-    return unless $self->_has_content_type();
+    return unless $self->_has_content_type;
 
-    $self->headers()->replace( 'Content-Type' => $self->content_type() );
+    $self->headers->replace( 'Content-Type' => $self->content_type );
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _stream_to {
     my $self   = shift;
     my $output = shift;
 
-    $self->headers()->stream_to( output => $output );
+    $self->headers->stream_to( output => $output );
     $output->($Courriel::Helpers::CRLF);
     $self->_stream_content($output);
 
     return;
 }
+## use critic;
 
 {
     my $fake_ct = Courriel::Header::ContentType->new_from_value(
@@ -84,7 +85,7 @@ sub _stream_to {
     sub _build_content_type {
         my $self = shift;
 
-        my @ct = $self->headers()->get('Content-Type');
+        my @ct = $self->headers->get('Content-Type');
         if ( @ct > 1 ) {
             die 'This part defines more than one Content-Type header.';
         }
